summaryrefslogtreecommitdiffstats
path: root/ipaserver/install/cainstance.py
diff options
context:
space:
mode:
Diffstat (limited to 'ipaserver/install/cainstance.py')
-rw-r--r--ipaserver/install/cainstance.py26
1 files changed, 12 insertions, 14 deletions
diff --git a/ipaserver/install/cainstance.py b/ipaserver/install/cainstance.py
index 6bbb6f545..5768e2939 100644
--- a/ipaserver/install/cainstance.py
+++ b/ipaserver/install/cainstance.py
@@ -285,7 +285,7 @@ class CADSInstance(service.Service):
_user_exists = self.restore_state("user_exists")
# At one time we removed this user on uninstall. That can potentially
- # orphan files, or worse, if another useradd runs in the intermim,
+ # orphan files, or worse, if another useradd runs in the interim,
# cause files to have a new owner.
@@ -325,6 +325,10 @@ class CAInstance(DogtagInstance):
self.ra_agent_pwd = self.ra_agent_db + "/pwdfile.txt"
self.ra_cert = None
self.requestId = None
+ self.tracking_nicknames = ['Server-Cert cert-pki-ca',
+ 'auditSigningCert cert-pki-ca',
+ 'ocspSigningCert cert-pki-ca',
+ 'subsystemCert cert-pki-ca']
def configure_instance(self, host_name, domain, dm_password,
admin_password, ds_port=DEFAULT_DSPORT,
@@ -713,7 +717,7 @@ class CAInstance(DogtagInstance):
os.write(admin_fd, self.admin_password)
os.close(admin_fd)
- # Look thru the cert chain to get all the certs we need to add
+ # Look through the cert chain to get all the certs we need to add
# trust for
p = subprocess.Popen(["/usr/bin/certutil", "-d", self.agent_db,
"-O", "-n", "ipa-ca-agent"], stdout=subprocess.PIPE)
@@ -899,7 +903,7 @@ class CAInstance(DogtagInstance):
try:
ipautil.run(["/usr/bin/pk12util",
"-n", "ipa-ca-agent",
- "-o", "/root/ca-agent.p12",
+ "-o", DogtagInstance.AGENT_P12_PATH,
"-d", self.agent_db,
"-k", pwd_name,
"-w", pwd_name])
@@ -925,7 +929,7 @@ class CAInstance(DogtagInstance):
"-print_certs",
], stdin=data)
- # Ok, now we have all the certificates in certs, walk thru it
+ # Ok, now we have all the certificates in certs, walk through it
# and pull out each certificate and add it to our database
st = 1
@@ -1201,7 +1205,7 @@ class CAInstance(DogtagInstance):
root_logger.critical("failed to uninstall CA instance %s" % e)
# At one time we removed this user on uninstall. That can potentially
- # orphan files, or worse, if another useradd runs in the intermim,
+ # orphan files, or worse, if another useradd runs in the interim,
# cause files to have a new owner.
_user_exists = self.restore_state("user_exists")
@@ -1316,16 +1320,10 @@ class CAInstance(DogtagInstance):
root_logger.error(
"certmonger failed to start tracking certificate: %s" % e)
- def stop_tracking_system_certificates(self, dogtag_constants):
- """Stop tracking our certificates. Called on uninstall.
+ @staticmethod
+ def stop_tracking_agent_certificate(dogtag_constants):
+ """Stop tracking agent certificate. Called on uninstall.
"""
- nicknames = ['Server-Cert cert-pki-ca',
- 'auditSigningCert cert-pki-ca',
- 'ocspSigningCert cert-pki-ca',
- 'subsystemCert cert-pki-ca']
- DogtagInstance.stop_tracking_certificates(
- self, dogtag_constants, nicknames)
-
cmonger = ipaservices.knownservices.certmonger
ipaservices.knownservices.messagebus.start()
cmonger.start()